# ORKG NLP PyPI
[![Documentation Status](https://readthedocs.org/projects/orkg-nlp-pypi/badge/?version=latest)](https://orkg-nlp-pypi.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/orkgnlp.svg)](https://badge.fury.io/py/orkgnlp)
[![pipeline status](https://gitlab.com/TIBHannover/orkg/nlp/orkg-nlp-pypi/badges/main/pipeline.svg)](https://gitlab.com/TIBHannover/orkg/nlp/orkg-nlp-pypi/-/commits/main)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

PyPI package wrapping the ORKG NLP services.

Check our [Read the Docs](https://orkg-nlp-pypi.readthedocs.io/en/latest/) for more details!

Your [contribution](https://orkg-nlp-pypi.readthedocs.io/en/latest/contribute.html) to `orkgnlp` will always be honored!
